tlslite.utils.TripleDES.TripleDES

Package tlslite :: Package utils :: Module TripleDES :: Class TripleDES |
[show private | hide private]
[frames | no frames]

## Class TripleDES

Known Subclasses:
  `Cryptlib_TripleDES`, `OpenSSL_TripleDES`, `PyCrypto_TripleDES`

Method Summary
| `__init__(self, key, mode, IV, implementation)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net